SharedPreferenceHelper class

Constructors

SharedPreferenceHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDisplayName() → Future<String?>
getUserEmail() → Future<String?>
getUserId() → Future<String?>
getUserName() → Future<String?>
getUserProfileUrl() → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveDisplayName(String getDisplayName) → Future<bool>
saveUserEmail(String getUseremail) → Future<bool>
saveUserId(String getUserId) → Future<bool>
saveUserName(String getUserName) → Future<bool>
saveUserProfileUrl(String getUserProfile) → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

displayNameKey ↔ String
getter/setter pair
userEmailKey ↔ String
getter/setter pair
userIdKey ↔ String
getter/setter pair
userNameKey ↔ String
getter/setter pair
userProfilePicKey ↔ String
getter/setter pair